@@ -4,7 +4,8 @@ export default function PropertyHidden(_ref) {
   var value = _ref.value,
       onUpdate = _ref.onUpdate,
       configs = _ref.configs,
-      sourceElement = _ref.sourceElement;
+      sourceElement = _ref.sourceElement,
+      internalState = _ref.internalState;
 
   return null;
 }
@@ -13,5 +14,6 @@ PropertyHidden.propTypes = {
   value: PropTypes.any.isRequired,
   onUpdate: PropTypes.func.isRequired,
   configs: PropTypes.object.isRequired,
-  sourceElement: PropTypes.object
+  sourceElement: PropTypes.object,
+  internalState: PropTypes.object
 };
\ No newline at end of file
