@@ -14,15 +14,15 @@ import If from '../../utils/react-if';
 import { Seq } from 'immutable';
 
 var STYLE_BOX = {
-  width: "220px",
-  height: "220px",
-  padding: "10px",
+  width: "13.75em",
+  height: "13.75em",
+  padding: "0.625em",
   background: "#f7f7f9",
   border: "1px solid #e1e1e8",
-  margin: "5px",
+  margin: "0.3em",
   cursor: "pointer",
   position: "relative",
-  boxShadow: "rgba(0, 0, 0, 0.117647) 0px 1px 6px, rgba(0, 0, 0, 0.117647) 0px 1px 4px",
+  boxShadow: "0 1px 6px 0 rgba(0, 0, 0, 0.11), 0 1px 4px 0 rgba(0, 0, 0, 0.11)",
   borderRadius: "2px"
 };
 
@@ -31,20 +31,27 @@ var STYLE_BOX_HOVER = _extends({}, STYLE_BOX, {
 });
 
 var STYLE_IMAGE = {
-  width: "200px",
-  height: "130px",
   background: "#222",
   marginBottom: "5px",
-  border: "solid 1px #e6e6e6"
+  border: "solid 1px #e6e6e6",
+  width: '100%',
+  height: '8em',
+  backgroundSize: 'contain',
+  backgroundPosition: '50% 50%',
+  backgroundColor: '#FFF',
+  backgroundRepeat: 'no-repeat'
 };
 
-var STYLE_TITLE = {
-  fontSize: "16px",
-  fontWeight: "bold"
+var STYLE_PLUS_HOVER = {
+  marginTop: '1.5em',
+  color: "#1ca6fc",
+  fontSize: "2em",
+  opacity: "0.7",
+  width: '100%'
 };
 
 var STYLE_DESCRIPTION = {
-  fontSize: "12px"
+  fontSize: "0.75em"
 };
 
 var STYLE_ICON = {
@@ -53,16 +60,6 @@ var STYLE_ICON = {
   right: "10px"
 };
 
-var STYLE_SELECT = {
-  position: "absolute",
-  top: "55px",
-  color: "#1ca6fc",
-  textAlign: "center",
-  width: "200px",
-  fontSize: "30px",
-  opacity: "0.7"
-};
-
 var STYLE_TAGS = {
   listStyle: "none",
   margin: "0px",
@@ -122,11 +119,10 @@ var CatalogItem = function (_Component) {
       var element = this.props.element;
       var hover = this.state.hover;
 
-
       return React.createElement(
         'div',
         { style: hover ? STYLE_BOX_HOVER : STYLE_BOX,
-          onClick: function onClick(event) {
+          onClick: function onClick(e) {
             return _this2.select();
           },
           onMouseEnter: function onMouseEnter(e) {
@@ -135,19 +131,14 @@ var CatalogItem = function (_Component) {
           onMouseLeave: function onMouseLeave(e) {
             return _this2.setState({ hover: false });
           } },
-        React.createElement('img', { style: STYLE_IMAGE, src: element.info.image }),
-        React.createElement(
-          If,
-          { condition: hover },
-          React.createElement(
-            'div',
-            { style: STYLE_SELECT },
-            React.createElement(IconAdd, null)
-          )
-        ),
         React.createElement(
           'div',
-          { style: STYLE_TITLE },
+          { style: _extends({}, STYLE_IMAGE, { backgroundImage: 'url(' + element.info.image + ')' }) },
+          hover ? React.createElement(IconAdd, { style: STYLE_PLUS_HOVER }) : null
+        ),
+        React.createElement(
+          'b',
+          null,
           element.info.title
         ),
         React.createElement(
@@ -166,11 +157,7 @@ var CatalogItem = function (_Component) {
           { style: STYLE_DESCRIPTION },
           element.info.description
         ),
-        React.createElement(
-          'div',
-          { style: STYLE_ICON },
-          React.createElement(IconAdd, null)
-        )
+        React.createElement(IconAdd, { style: STYLE_ICON })
       );
     }
   }]);
