@@ -5,7 +5,7 @@ import Button from '../../components/style/button';
 const tableStyle = { width: "100%", borderSpacing: "2px 0", marginBottom: "2px" };
 const firstTdStyle = { width: '6em' };
 
-export default function PropertyToggle({value, onUpdate, configs, sourceElement}) {
+export default function PropertyToggle({value, onUpdate, configs, sourceElement, internalState}) {
   return (
     <table className="PropertyToggle" style={tableStyle}>
       <tbody>
@@ -24,5 +24,6 @@ PropertyToggle.propTypes = {
   value: PropTypes.any.isRequired,
   onUpdate: PropTypes.func.isRequired,
   configs: PropTypes.object.isRequired,
-  sourceElement: PropTypes.object
+  sourceElement: PropTypes.object,
+  internalState: PropTypes.object
 };
